package Qt::Gui::QAccessiblePlugin;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QAccessiblePlugin
# file     : QtGui/qaccessibleplugin.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QAccessibleFactoryInterface/;
#our @ISA = qw/Qt::Gui::QAccessibleFactoryInterface/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QAccessiblePlugin

=head1 PUBLIC METHODS

=over

=item   QAccessiblePlugin(QObject * parent)

=item   QAccessiblePlugin(QObject * parent = 0)

=item   ~QAccessiblePlugin()

=item  QAccessibleInterface * create(const QString & key, QObject * object)

=item  QStringList keys()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
